@@ -1,7 +1,7 @@
 context("test-print")
 
 set.seed(42)
-csr_pattern <- spatstat.core::runifpoint(n = 100)
+csr_pattern <- spatstat.random::runifpoint(n = 100)
 
 csr_envelope <- spatstat.core::envelope(csr_pattern, fun = "pcf", nsim = 199,
                                         funargs = list(divisor = "d",
